@@ -1,18 +1,12 @@
 import re
-
 import gi
 
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk, Pango
-
 from ks_includes.KlippyGcodes import KlippyGcodes
 from ks_includes.screen_panel import ScreenPanel
 
 
-def create_panel(*args):
-    return InputShaperPanel(*args)
-
-
 # X and Y frequencies
 XY_FREQ = [
     {'name': 'X', 'config': 'shaper_freq_x', 'min': 0, 'max': 133},
@@ -21,7 +15,7 @@ XY_FREQ = [
 SHAPERS = ['zv', 'mzv', 'zvd', 'ei', '2hump_ei', '3hump_ei']
 
 
-class InputShaperPanel(ScreenPanel):
+class Panel(ScreenPanel):
     def __init__(self, screen, title):
         super().__init__(screen, title)
         self.freq_xy_adj = {}
@@ -29,7 +23,7 @@ class InputShaperPanel(ScreenPanel):
         self.calibrate_btn = self._gtk.Button("move", _('Finding ADXL'), "color1", lines=1)
         self.calibrate_btn.connect("clicked", self.on_popover_clicked)
         self.calibrate_btn.set_sensitive(False)
-        self.status = Gtk.Label("")
+        self.status = Gtk.Label()
         self.status.set_hexpand(True)
         self.status.set_vexpand(False)
         self.status.set_halign(Gtk.Align.START)
