@@ -1,42 +1,38 @@
 # -*- coding: utf-8 -*-
 import logging
 import os
-import contextlib
 import gi
 
 gi.require_version("Gtk", "3.0")
 from gi.repository import GLib, Gtk, Pango
-from ks_includes.screen_panel import ScreenPanel
+from contextlib import suppress
 from math import pi, sqrt
 from statistics import median
 from time import time
+from ks_includes.screen_panel import ScreenPanel
 
 
-def create_panel(*args):
-    return JobStatusPanel(*args)
-
-
-class JobStatusPanel(ScreenPanel):
+class Panel(ScreenPanel):
     def __init__(self, screen, title):
         super().__init__(screen, title)
         self.grid = self._gtk.HomogeneousGrid()
         self.grid.set_row_homogeneous(False)
-        self.pos_z = 0
+        self.pos_z = 0.0
         self.extrusion = 100
-        self.speed_factor = 1
+        self.speed_factor = 1.0
         self.speed = 100
         self.req_speed = 0
         self.f_layer_h = self.layer_h = 1
-        self.oheight = 0
+        self.oheight = 0.0
         self.current_extruder = None
-        self.fila_section = 0
+        self.fila_section = 0.0
         self.filename_label = self.filename = self.prev_pos = self.prev_gpos = None
         self.can_close = False
         self.flow_timeout = self.animation_timeout = None
         self.file_metadata = self.fans = {}
         self.state = "standby"
         self.timeleft_type = "auto"
-        self.progress = self.zoffset = self.flowrate = self.vel = 0
+        self.progress = self.zoffset = self.flowrate = self.vel = 0.0
         self.flowstore = []
         self.mm = _("mm")
         self.mms = _("mm/s")
@@ -50,7 +46,7 @@ class JobStatusPanel(ScreenPanel):
                 'flowrate']
 
         for item in data:
-            self.labels[item] = Gtk.Label("-")
+            self.labels[item] = Gtk.Label(label="-")
             self.labels[item].set_vexpand(True)
             self.labels[item].set_hexpand(True)
 
@@ -86,12 +82,12 @@ class JobStatusPanel(ScreenPanel):
                 "speed": "-"
             }
 
-        self.labels['file'] = Gtk.Label("Filename")
+        self.labels['file'] = Gtk.Label(label="Filename")
         self.labels['file'].get_style_context().add_class("printing-filename")
         self.labels['file'].set_hexpand(True)
-        self.labels['status'] = Gtk.Label("Status")
+        self.labels['status'] = Gtk.Label(label="Status")
         self.labels['status'].get_style_context().add_class("printing-status")
-        self.labels['lcdmessage'] = Gtk.Label("")
+        self.labels['lcdmessage'] = Gtk.Label()
         self.labels['lcdmessage'].get_style_context().add_class("printing-status")
 
         for label in self.labels:
@@ -109,7 +105,7 @@ class JobStatusPanel(ScreenPanel):
 
         box = Gtk.Box()
         box.set_halign(Gtk.Align.CENTER)
-        self.labels['progress_text'] = Gtk.Label("0%")
+        self.labels['progress_text'] = Gtk.Label(label="0%")
         self.labels['progress_text'].get_style_context().add_class("printing-progress-text")
         box.add(self.labels['progress_text'])
 
@@ -152,21 +148,21 @@ class JobStatusPanel(ScreenPanel):
         }
         for button in buttons:
             buttons[button].set_halign(Gtk.Align.START)
-        buttons['fan'].connect("clicked", self.menu_item_clicked, "fan", {"panel": "fan", "name": _("Fan")})
+        buttons['fan'].connect("clicked", self.menu_item_clicked, {"panel": "fan", "name": _("Fan")})
         self.buttons.update(buttons)
 
         self.labels['temp_grid'] = Gtk.Grid()
-        nlimit = 2 if self._screen.width <= 480 else 3
+        nlimit = 2 if self._screen.width <= 500 else 3
         n = 0
         self.buttons['extruder'] = {}
         if self._printer.get_tools():
             self.current_extruder = self._printer.get_stat("toolhead", "extruder")
             for i, extruder in enumerate(self._printer.get_tools()):
-                self.labels[extruder] = Gtk.Label("-")
+                self.labels[extruder] = Gtk.Label(label="-")
                 self.buttons['extruder'][extruder] = self._gtk.Button(f"extruder-{i}", "", None, self.bts,
                                                                       Gtk.PositionType.LEFT, 1)
                 self.buttons['extruder'][extruder].set_label(self.labels[extruder].get_text())
-                self.buttons['extruder'][extruder].connect("clicked", self.menu_item_clicked, "temperature",
+                self.buttons['extruder'][extruder].connect("clicked", self.menu_item_clicked,
                                                            {"panel": "temperature", "name": _("Temperature"),
                                                             'extra': self.current_extruder})
                 self.buttons['extruder'][extruder].set_halign(Gtk.Align.START)
@@ -177,9 +173,9 @@ class JobStatusPanel(ScreenPanel):
         self.buttons['heater'] = {}
         if self._printer.has_heated_bed():
             self.buttons['heater']['heater_bed'] = self._gtk.Button("bed", "", None, self.bts, Gtk.PositionType.LEFT, 1)
-            self.labels['heater_bed'] = Gtk.Label("-")
+            self.labels['heater_bed'] = Gtk.Label(label="-")
             self.buttons['heater']['heater_bed'].set_label(self.labels['heater_bed'].get_text())
-            self.buttons['heater']['heater_bed'].connect("clicked", self.menu_item_clicked, "temperature",
+            self.buttons['heater']['heater_bed'].connect("clicked", self.menu_item_clicked,
                                                          {"panel": "temperature", "name": _("Temperature"),
                                                           'extra': 'heater_bed'})
             self.buttons['heater']['heater_bed'].set_halign(Gtk.Align.START)
@@ -190,9 +186,9 @@ class JobStatusPanel(ScreenPanel):
                 break
             if dev.startswith("heater_generic"):
                 self.buttons['heater'][dev] = self._gtk.Button("heater", "", None, self.bts, Gtk.PositionType.LEFT, 1)
-                self.labels[dev] = Gtk.Label("-")
+                self.labels[dev] = Gtk.Label(label="-")
                 self.buttons['heater'][dev].set_label(self.labels[dev].get_text())
-                self.buttons['heater'][dev].connect("clicked", self.menu_item_clicked, "temperature",
+                self.buttons['heater'][dev].connect("clicked", self.menu_item_clicked,
                                                     {"panel": "temperature", "name": _("Temperature"), "extra": dev})
                 self.buttons['heater'][dev].set_halign(Gtk.Align.START)
                 self.labels['temp_grid'].attach(self.buttons['heater'][dev], n, 0, 1, 1)
@@ -215,9 +211,9 @@ class JobStatusPanel(ScreenPanel):
                                     break
                                 self.buttons['heater'][device] = self._gtk.Button("heat-up", "", None, self.bts,
                                                                                   Gtk.PositionType.LEFT, 1)
-                                self.labels[device] = Gtk.Label("-")
+                                self.labels[device] = Gtk.Label(label="-")
                                 self.buttons['heater'][device].set_label(self.labels[device].get_text())
-                                self.buttons['heater'][device].connect("clicked", self.menu_item_clicked, "temperature",
+                                self.buttons['heater'][device].connect("clicked", self.menu_item_clicked,
                                                                        {"panel": "temperature",
                                                                         "name": _("Temperature")})
                                 self.buttons['heater'][device].set_halign(Gtk.Align.START)
@@ -351,11 +347,6 @@ class JobStatusPanel(ScreenPanel):
         ctx.stroke()
 
     def activate(self):
-        ps = self._printer.get_stat("print_stats")
-        self.set_state(ps['state'])
-        if 'filename' in ps and (ps['filename'] != self.filename):
-            logging.debug(f"Changing filename: '{self.filename}' to '{ps['filename']}'")
-            self.update_filename()
         if self.flow_timeout is None:
             self.flow_timeout = GLib.timeout_add_seconds(2, self.update_flow)
         self._screen.base_panel_show_all()
@@ -380,7 +371,7 @@ class JobStatusPanel(ScreenPanel):
         }
         self.buttons['cancel'].connect("clicked", self.cancel)
         self.buttons['control'].connect("clicked", self._screen._go_to_submenu, "")
-        self.buttons['fine_tune'].connect("clicked", self.menu_item_clicked, "fine_tune", {
+        self.buttons['fine_tune'].connect("clicked", self.menu_item_clicked, {
             "panel": "fine_tune", "name": _("Fine Tuning")})
         self.buttons['menu'].connect("clicked", self.close_panel)
         self.buttons['pause'].connect("clicked", self.pause)
@@ -426,13 +417,16 @@ class JobStatusPanel(ScreenPanel):
             self._screen._ws.klippy.gcode_script("SAVE_CONFIG")
 
     def restart(self, widget):
-        if self.filename != "none":
+        if self.filename:
             self.disable_button("restart")
             if self.state == "error":
                 script = {"script": "SDCARD_RESET_FILE"}
                 self._screen._send_action(None, "printer.gcode.script", script)
             self._screen._ws.klippy.print_start(self.filename)
+            logging.info(f"Starting print: {self.filename}")
             self.new_print()
+        else:
+            logging.info(f"Could not restart {self.filename}")
 
     def resume(self, widget):
         self._screen._ws.klippy.print_resume()
@@ -465,7 +459,7 @@ class JobStatusPanel(ScreenPanel):
     def cancel_confirm(self, dialog, response_id):
         self._gtk.remove_dialog(dialog)
         if response_id == Gtk.ResponseType.APPLY:
-            self.menu_item_clicked(None, "exclude", {"panel": "exclude", "name": _("Exclude Object")})
+            self.menu_item_clicked(None, {"panel": "exclude", "name": _("Exclude Object")})
             return
         if response_id == Gtk.ResponseType.CANCEL:
             self.enable_button("pause", "cancel")
@@ -495,12 +489,12 @@ class JobStatusPanel(ScreenPanel):
 
     def new_print(self):
         self._screen.close_screensaver()
-        self.state_check()
+        self.update_progress(0.0)
 
     def process_update(self, action, data):
         if action == "notify_gcode_response":
             if "action:cancel" in data:
-                self.set_state("cancelling")
+                self.set_state("cancelled")
             elif "action:paused" in data:
                 self.set_state("paused")
             elif "action:resumed" in data:
@@ -528,43 +522,46 @@ class JobStatusPanel(ScreenPanel):
                 )
                 self.buttons['heater'][x].set_label(self.labels[x].get_text())
 
-        self.update_message()
+        if "display_status" in data and "message" in data["display_status"]:
+            self.labels['lcdmessage'].set_label(
+                f"{data['display_status']['message'] if data['display_status']['message'] is not None else ''}"
+            )
 
-        with contextlib.suppress(KeyError):
+        with suppress(KeyError):
             if data["toolhead"]["extruder"] != self.current_extruder:
                 self.labels['temp_grid'].remove_column(0)
                 self.labels['temp_grid'].insert_column(0)
                 self.current_extruder = data["toolhead"]["extruder"]
                 self.labels['temp_grid'].attach(self.buttons['extruder'][self.current_extruder], 0, 0, 1, 1)
                 self._screen.show_all()
-        with contextlib.suppress(KeyError):
+        with suppress(KeyError):
             self.labels['max_accel'].set_label(f"{data['toolhead']['max_accel']:.0f} {self.mms2}")
-        with contextlib.suppress(KeyError):
+        with suppress(KeyError):
             self.labels['advance'].set_label(f"{data['extruder']['pressure_advance']:.2f}")
 
         if "gcode_move" in data:
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.pos_z = round(float(data['gcode_move']['gcode_position'][2]), 2)
                 self.buttons['z'].set_label(f"Z: {self.pos_z:6.2f}{f'/{self.oheight}' if self.oheight > 0 else ''}")
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.extrusion = round(float(data["gcode_move"]["extrude_factor"]) * 100)
                 self.labels['extrude_factor'].set_label(f"{self.extrusion:3}%")
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.speed = round(float(data["gcode_move"]["speed_factor"]) * 100)
                 self.speed_factor = float(data["gcode_move"]["speed_factor"])
                 self.labels['speed_factor'].set_label(f"{self.speed:3}%")
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.req_speed = round(float(data["gcode_move"]["speed"]) / 60 * self.speed_factor)
                 self.labels['req_speed'].set_label(
                     f"{self.speed}% {self.vel:3.0f}/{self.req_speed:3.0f} "
                     f"{f'{self.mms}' if self.vel < 1000 and self.req_speed < 1000 and self._screen.width > 500 else ''}"
                 )
                 self.buttons['speed'].set_label(self.labels['req_speed'].get_label())
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.zoffset = float(data["gcode_move"]["homing_origin"][2])
                 self.labels['zoffset'].set_label(f"{self.zoffset:.3f} {self.mm}")
         if "motion_report" in data:
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.labels['pos_x'].set_label(f"X: {data['motion_report']['live_position'][0]:6.2f}")
                 self.labels['pos_y'].set_label(f"Y: {data['motion_report']['live_position'][1]:6.2f}")
                 self.labels['pos_z'].set_label(f"Z: {data['motion_report']['live_position'][2]:6.2f}")
@@ -576,52 +573,52 @@ class JobStatusPanel(ScreenPanel):
                     evelocity = (pos[3] - self.prev_pos[0][3]) / interval
                     self.flowstore.append(self.fila_section * evelocity)
                 self.prev_pos = [pos, now]
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.vel = float(data["motion_report"]["live_velocity"])
                 self.labels['req_speed'].set_label(
                     f"{self.speed}% {self.vel:3.0f}/{self.req_speed:3.0f} "
                     f"{f'{self.mms}' if self.vel < 1000 and self.req_speed < 1000 and self._screen.width > 500 else ''}"
                 )
                 self.buttons['speed'].set_label(self.labels['req_speed'].get_label())
-            with contextlib.suppress(KeyError):
+            with suppress(KeyError):
                 self.flowstore.append(self.fila_section * float(data["motion_report"]["live_extruder_velocity"]))
         fan_label = ""
         for fan in self.fans:
-            with contextlib.suppress(KeyError):
-                self.fans[fan]['speed'] = f"{self._printer.get_fan_speed(fan) * 100:3.0f}%"
-                fan_label += f" {self.fans[fan]['name']}{self.fans[fan]['speed']}"
+            self.fans[fan]['speed'] = f"{self._printer.get_fan_speed(fan) * 100:3.0f}%"
+            fan_label += f" {self.fans[fan]['name']}{self.fans[fan]['speed']}"
         if fan_label:
             self.buttons['fan'].set_label(fan_label[:12])
-
-        self.state_check()
-        if self.state not in ["printing", "paused"]:
-            return
-
-        ps = self._printer.get_stat("print_stats")
-        if 'filename' in ps and (ps['filename'] != self.filename):
-            logging.debug(f"Changing filename: '{self.filename}' to '{ps['filename']}'")
-            self.update_filename()
-        else:
-            self.update_percent_complete()
-        if 'info' in ps and 'total_layer' in ps['info'] and ps['info']['total_layer'] is not None:
-            self.labels['total_layers'].set_label(f"{ps['info']['total_layer']}")
-        if 'info' in ps and 'current_layer' in ps['info'] and ps['info']['current_layer'] is not None:
-            self.labels['layer'].set_label(f"{ps['info']['current_layer']} / {self.labels['total_layers'].get_text()}")
-        elif "layer_height" in self.file_metadata and "object_height" in self.file_metadata:
-            self.labels['layer'].set_label(
-                f"{1 + round((self.pos_z - self.f_layer_h) / self.layer_h)} / {self.labels['total_layers'].get_text()}")
-
-        if 'print_duration' in ps:
-            if 'filament_used' in ps:
-                self.labels['filament_used'].set_label(f"{float(ps['filament_used']) / 1000:.1f} m")
-                self.update_time_left(ps['total_duration'], ps['print_duration'], ps['filament_used'])
-            else:
-                self.update_time_left(ps['total_duration'], ps['print_duration'])
-
-        elapsed_label = f"{self.labels['elapsed'].get_text()}  {self.labels['duration'].get_text()}"
-        self.buttons['elapsed'].set_label(elapsed_label)
-        remaining_label = f"{self.labels['left'].get_text()}  {self.labels['time_left'].get_text()}"
-        self.buttons['left'].set_label(remaining_label)
+        if "print_stats" in data:
+            with suppress(KeyError):
+                self.set_state(
+                    data["print_stats"]["state"],
+                    msg=f'{data["print_stats"]["message"] if "message" in data["print_stats"] else ""}'
+                )
+            with suppress(KeyError):
+                self.update_filename(data['print_stats']["filename"])
+            with suppress(KeyError):
+                if 'print_duration' in data["print_stats"]:
+                    if 'filament_used' in data["print_stats"]:
+                        self.labels['filament_used'].set_label(
+                            f"{float(data['print_stats']['filament_used']) / 1000:.1f} m"
+                        )
+            if 'info' in data["print_stats"]:
+                with suppress(KeyError):
+                    if data["print_stats"]['info']['total_layer'] is not None:
+                        self.labels['total_layers'].set_label(f"{data['print_stats']['info']['total_layer']}")
+                with suppress(KeyError):
+                    if data["print_stats"]['info']['current_layer'] is not None:
+                        self.labels['layer'].set_label(
+                            f"{data['print_stats']['info']['current_layer']} / "
+                            f"{self.labels['total_layers'].get_text()}"
+                        )
+            elif "layer_height" in self.file_metadata and "object_height" in self.file_metadata:
+                self.labels['layer'].set_label(
+                    f"{1 + round((self.pos_z - self.f_layer_h) / self.layer_h)} / "
+                    f"{self.labels['total_layers'].get_text()}"
+                )
+            if self.state in ["printing"]:
+                self.update_time_left()
 
     def update_flow(self):
         if not self.flowstore:
@@ -632,26 +629,34 @@ class JobStatusPanel(ScreenPanel):
         self.buttons['extrusion'].set_label(f"{self.extrusion:3}% {self.flowrate:5.1f} {self.mms3}")
         return True
 
-    def update_time_left(self, total_duration, print_duration, fila_used=0):
+    def update_time_left(self):
+        total_duration = float(self._printer.get_stat('print_stats', 'total_duration'))
+        print_duration = float(self._printer.get_stat('print_stats', 'print_duration'))
+        if not print_duration:  # No-extrusion
+            print_duration = total_duration
+        fila_used = float(self._printer.get_stat('print_stats', 'filament_used'))
+        progress = float(self._printer.get_stat("virtual_sdcard", "progress"))
         self.labels["duration"].set_label(self.format_time(total_duration))
+        elapsed_label = f"{self.labels['elapsed'].get_text()}  {self.labels['duration'].get_text()}"
+        self.buttons['elapsed'].set_label(elapsed_label)
         non_printing = total_duration - print_duration
         estimated = None
         slicer_time = filament_time = file_time = None
         timeleft_type = self._config.get_config()['main'].get('print_estimate_method', 'auto')
 
-        with contextlib.suppress(KeyError):
+        with suppress(KeyError):
             if self.file_metadata['estimated_time'] > 0:
                 # speed_factor compensation based on empirical testing
                 spdcomp = sqrt(self.speed_factor)
                 slicer_time = ((self.file_metadata['estimated_time']) / spdcomp) + non_printing
         self.labels["slicer_time"].set_label(self.format_time(slicer_time))
 
-        with contextlib.suppress(Exception):
+        with suppress(Exception):
             if self.file_metadata['filament_total'] > fila_used:
-                filament_time = (total_duration / (fila_used / self.file_metadata['filament_total'])) + non_printing
+                filament_time = (print_duration / (fila_used / self.file_metadata['filament_total'])) + non_printing
         self.labels["filament_time"].set_label(self.format_time(filament_time))
-        with contextlib.suppress(ZeroDivisionError):
-            file_time = (total_duration / self.progress) + non_printing
+        with suppress(ZeroDivisionError):
+            file_time = (print_duration / progress) + non_printing
         self.labels["file_time"].set_label(self.format_time(file_time))
 
         if timeleft_type == "file":
@@ -661,71 +666,58 @@ class JobStatusPanel(ScreenPanel):
         elif slicer_time is not None:
             if timeleft_type == "slicer":
                 estimated = slicer_time
-            elif filament_time is not None and self.progress > 0.14:
+            elif filament_time is not None and progress > 0.14:
                 # Weighted arithmetic mean (Slicer is the most accurate)
                 estimated = (slicer_time * 3 + filament_time + file_time) / 5
             else:
                 # At the begining file and filament are innacurate
                 estimated = slicer_time
-        elif file_time is not None:
-            if filament_time is not None:
+        if (estimated is None or estimated < 1) and file_time is not None:
+            if filament_time is not None and filament_time > 1:
                 estimated = (filament_time + file_time) / 2
-            else:
-                estimated = file_time
+            estimated = file_time
         self.labels["est_time"].set_label(self.format_time(estimated))
         self.labels["time_left"].set_label(self.format_eta(estimated, total_duration))
+        remaining_label = f"{self.labels['left'].get_text()}  {self.labels['time_left'].get_text()}"
+        self.buttons['left'].set_label(remaining_label)
+        self.update_progress(min(max(total_duration / estimated, 0), 1))
 
-    def state_check(self):
-        ps = self._printer.get_stat("print_stats")
+    def update_progress(self, progress: float):
+        self.progress = progress
+        self.labels['progress_text'].set_label(f"{progress * 100:.0f}%")
+        self.labels['darea'].queue_draw()
 
-        if 'state' not in ps or ps['state'] == self.state:
-            return True
-
-        if ps['state'] == "printing":
-            if self.state == "cancelling":
-                return True
-            self.set_state("printing")
-            self.update_filename()
-        elif ps['state'] == "complete":
-            self.progress = 1
-            self.update_progress()
-            self.set_state("complete")
-            return self._add_timeout(self._config.get_main_config().getint("job_complete_timeout", 0))
-        elif ps['state'] == "error":
-            self.set_state("error")
+    def set_state(self, state, msg=""):
+        if state == "printing":
+            self.labels["status"].set_label(_("Printing"))
+        elif state == "complete":
+            self.update_progress(1)
+            self.labels["status"].set_label(_("Complete"))
+            self.buttons['left'].set_label("-")
+            self._add_timeout(self._config.get_main_config().getint("job_complete_timeout", 0))
+        elif state == "error":
             self.labels['status'].set_label(_("Error"))
-            self._screen.show_popup_message(ps['message'])
-            return self._add_timeout(self._config.get_main_config().getint("job_error_timeout", 0))
-        elif ps['state'] == "cancelled":
-            self.set_state("cancelled")
-            return self._add_timeout(self._config.get_main_config().getint("job_cancelled_timeout", 0))
-        elif ps['state'] == "paused":
-            self.set_state("paused")
-        elif ps['state'] == "standby":
-            self.set_state("standby")
-        return True
+            self._screen.show_popup_message(msg)
+            self._add_timeout(self._config.get_main_config().getint("job_error_timeout", 0))
+        elif state == "cancelling":
+            self.labels["status"].set_label(_("Cancelling"))
+        elif state == "cancelled" or (state == "standby" and self.state == "cancelled"):
+            self.labels["status"].set_label(_("Cancelled"))
+            self._add_timeout(self._config.get_main_config().getint("job_cancelled_timeout", 0))
+        elif state == "paused":
+            self.labels["status"].set_label(_("Paused"))
+        elif state == "standby":
+            self.labels["status"].set_label(_("Standby"))
+        if self.state != state:
+            logging.debug(f"Changing job_status state from '{self.state}' to '{state}'")
+            self.state = state
+        self.show_buttons_for_state()
 
     def _add_timeout(self, timeout):
         self._screen.close_screensaver()
         if timeout != 0:
             GLib.timeout_add_seconds(timeout, self.close_panel)
 
-    def set_state(self, state):
-        if self.state != state:
-            logging.debug(f"Changing job_status state from '{self.state}' to '{state}'")
-        if state == "paused":
-            self.labels["status"].set_label(_("Paused"))
-        elif state == "printing":
-            self.labels["status"].set_label(_("Printing"))
-        elif state == "cancelling":
-            self.labels["status"].set_label(_("Cancelling"))
-        elif state == "cancelled" or (state == "standby" and self.state == "cancelling"):
-            self.labels["status"].set_label(_("Cancelled"))
-        elif state == "complete":
-            self.labels["status"].set_label(_("Complete"))
-        self.state = state
-        self.show_buttons_for_state()
-
     def show_buttons_for_state(self):
         self.buttons['button_grid'].remove_row(0)
         self.buttons['button_grid'].insert_row(0)
@@ -747,21 +739,26 @@ class JobStatusPanel(ScreenPanel):
             offset = self._printer.get_stat("gcode_move", "homing_origin")
             self.zoffset = float(offset[2]) if offset else 0
             if self.zoffset != 0:
-                endstop = (self._printer.config_section_exists("stepper_z") and
-                           not self._printer.get_config_section("stepper_z")['endstop_pin'].startswith("probe"))
+                endstop = (
+                    (
+                        self._printer.config_section_exists("stepper_z")
+                        and not self._printer.get_config_section("stepper_z")['endstop_pin'].startswith("probe")
+                    )
+                    or "delta" in self._printer.get_config_section("printer")['kinematics']
+                )
                 if endstop:
                     self.buttons['button_grid'].attach(self.buttons["save_offset_endstop"], 0, 0, 1, 1)
                 else:
-                    self.buttons['button_grid'].attach(Gtk.Label(""), 0, 0, 1, 1)
+                    self.buttons['button_grid'].attach(Gtk.Label(), 0, 0, 1, 1)
                 if self._printer.get_probe():
                     self.buttons['button_grid'].attach(self.buttons["save_offset_probe"], 1, 0, 1, 1)
                 else:
-                    self.buttons['button_grid'].attach(Gtk.Label(""), 1, 0, 1, 1)
+                    self.buttons['button_grid'].attach(Gtk.Label(), 1, 0, 1, 1)
             else:
-                self.buttons['button_grid'].attach(Gtk.Label(""), 0, 0, 1, 1)
-                self.buttons['button_grid'].attach(Gtk.Label(""), 1, 0, 1, 1)
+                self.buttons['button_grid'].attach(Gtk.Label(), 0, 0, 1, 1)
+                self.buttons['button_grid'].attach(Gtk.Label(), 1, 0, 1, 1)
 
-            if self.filename is not None:
+            if self.filename:
                 self.buttons['button_grid'].attach(self.buttons['restart'], 2, 0, 1, 1)
                 self.enable_button("restart")
             else:
@@ -785,8 +782,10 @@ class JobStatusPanel(ScreenPanel):
             pixbuf = self._gtk.PixbufFromIcon("file", width / 2, height / 2)
         self.labels['thumbnail'].set_from_pixbuf(pixbuf)
 
-    def update_filename(self):
-        self.filename = self._printer.get_stat('print_stats', 'filename')
+    def update_filename(self, filename):
+        if not filename:
+            return
+        self.filename = filename
         self.labels["file"].set_label(os.path.splitext(self.filename)[0])
         self.filename_label = {
             "complete": self.labels['file'].get_label(),
@@ -797,7 +796,6 @@ class JobStatusPanel(ScreenPanel):
         }
         if self.animation_timeout is None and (self.filename_label['length'] - self.filename_label['limit']) > 0:
             self.animation_timeout = GLib.timeout_add_seconds(1, self.animate_label)
-        self.update_percent_complete()
         self.update_file_metadata()
 
     def animate_label(self):
@@ -833,28 +831,3 @@ class JobStatusPanel(ScreenPanel):
             logging.debug("Cannot find file metadata. Listening for updated metadata")
             self._screen.files.add_file_callback(self._callback_metadata)
         self.show_file_thumbnail()
-
-    def update_percent_complete(self):
-        if self.state not in ["printing", "paused"]:
-            return
-
-        if "gcode_start_byte" in self.file_metadata:
-            progress = (max(self._printer.get_stat('virtual_sdcard', 'file_position') -
-                            self.file_metadata['gcode_start_byte'], 0) / (self.file_metadata['gcode_end_byte'] -
-                                                                          self.file_metadata['gcode_start_byte']))
-        else:
-            progress = self._printer.get_stat('virtual_sdcard', 'progress')
-
-        if progress != self.progress:
-            self.progress = progress
-            self.labels['darea'].queue_draw()
-            self.update_progress()
-
-    def update_progress(self):
-        self.labels['progress_text'].set_label(f"{self.progress * 100:.0f}%")
-
-    def update_message(self):
-        msg = self._printer.get_stat("display_status", "message")
-        if msg is None:
-            msg = " "
-        self.labels['lcdmessage'].set_label(f"{msg}")
